;; Generated package description from timeout.el  -*- no-byte-compile: t -*-
(define-package "timeout" "2.0.0.20250907.203430" "Throttle or debounce Elisp functions" '((emacs "24.4")) :commit "f3ebb53ef15aaa302d9c92863cb4a5d99419e89d" :authors '(("Karthik Chikmagalur" . "karthikchikmagalur@gmail.com")) :maintainer '("Karthik Chikmagalur" . "karthikchikmagalur@gmail.com") :keywords '("convenience" "extensions") :url "https://github.com/karthink/timeout")
